# dbdts.db
Documentation can be found [here](https://leref.github.io/dbdts.db)

[![NPM Downloads](https://img.shields.io/npm/dt/dbdts.db.svg?maxAge=3600)](https://www.npmjs.com/package/dbdts.db)
[![NPM Version](https://img.shields.io/npm/v/dbdts.db.svg?maxAge=3600)](https://www.npmjs.com/package/dbdts.db)
[![Discord Server](https://img.shields.io/discord/773352845738115102?color=5865F2&logo=discord&logoColor=white)](https://discord.com/invite/HMUfMXDQsV)

## Example
This is a small example of how you would create a database instance and a table with 2 columns with a primary column and a json column, connecting database and doing some operations with it.
```js
const { Database, Column, Table } = require("dbdts.db")

const db = new Database({ path: "./db.sqlite" })

const table = db.createTable("mytable").addColumns([
    new Column()
    .setName("id")
    .setPrimary(true)
    .setType("TEXT"),
    new Column()
    .setName("json")
    .setType("JSON")
    .setDefault({})
])

db.once("ready", () => {
    console.log(`Database is ready!`)

    const changes = table.set({
        id: "12345",
        json: {
            swords: 1,
            hammers: 0
        }
    })

    console.log(changes)

    const results = table.get({
        where: {
            column: "id",
            equals: "12345"
        }
    })

    console.log(results)

    const deletion = table.delete({
        where: {
            column: "id",
            equals: "12345"
        }
    })

    console.log(deletion)

    const all = table.all()

    console.log(all)
})

db.connect()
```

## Creating an API Database:
```js
const { APIDatabase, Column } = require("dbdts.db")

//You will need to install axios yourself.
const axios = require("axios")

const table = db.createTable("mytable").addColumns([
    new Column()
    .setName("id")
    .setPrimary(true)
    .setType("TEXT"),
    new Column()
    .setName("json")
    .setType("JSON")
    .setDefault({})
])

const db = new APIDatabase({
    port: 3444,
    password: "youshallnotpass"
})


db.open(async () => {
    console.log(`Database ready!`)

    await axios.post(`${db.url}/set`, {
        table: "mytable",
        data: {
            id: "12345",
            json: {
                swords: 1,
                hammers: 0
            }
        },
        options: {
            where: {
                column: "id",
                equals: "12345"
            }
        }
    }, {
        headers: {
            Authorization: db.options.password
        }
    })

    const request = await axios.post(`${db.url}/get`, {
        table: "mytable",
        options: {
            where: {
                column: "id",
                equals: "12345"
            }
        }
    }, {
        headers: {
            Authorization: db.options.password
        }
    })

    console.log(request.data)
})
```