"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIDatabase = void 0;
const Database_1 = __importDefault(require("./Database"));
const express_1 = __importDefault(require("express"));
/**
 * Manages api databases.
 */
class APIDatabase extends Database_1.default {
    /**
     *
     * @param options The options for this api database.
     */
    constructor(options) {
        super(options);
        /**
         * Undocumented.
         */
        this.app = (0, express_1.default)();
        this.options = this.validateOptions(options);
    }
    /**
     * Opens the database.
     * @param callback The callback fn that will be used once database is open.
     */
    open(callback) {
        return __awaiter(this, void 0, void 0, function* () {
            this.app.use(express_1.default.json());
            yield this.connect();
            this.app.listen(this.options.port, typeof callback === "function" ? callback : () => { });
            this.app.post("/get", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.get(req.body.table, req.body.options);
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.post("/all", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.all(req.body.table, req.body.options);
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.post("/set", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.set(req.body.table, req.body.data, req.body.options);
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.post("/insert", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.insert(req.body.table, req.body.data);
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.post("/delete", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.delete(req.body.table, req.body.options);
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.post("/vacuum", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    const got = this.vacuum();
                    res.json(got);
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
            this.app.get("/uptime", (req, res) => {
                if (!this.validatePassword(req.headers.authorization)) {
                    return res.status(401).json();
                }
                try {
                    res.json({
                        uptime: Date.now() - this.readyTimestamp
                    });
                }
                catch (error) {
                    if (error) {
                        res.status(400).json(error);
                    }
                }
            });
        });
    }
    /**
     * Axios object.
     */
    get axios() {
        return require("axios");
    }
    /**
     * Gets the host full url to api.
     */
    get url() {
        return `http://${this.options.host}:${this.options.port}`;
    }
    /**
     * Validates given password.
     * @param pass The password to validate.
     * @returns Boolean indicating whether this password is correct.
     */
    validatePassword(pass) {
        return !this.options.password || this.options.password === pass;
    }
    /**
     * Sanitizes given options to api database.
     * @param options The options to merge.
     * @returns An object with the new options.
     */
    validateOptions(options) {
        if (!options.port) {
            options.port = 3000;
        }
        if (!options.host) {
            options.host = "localhost";
        }
        return options;
    }
}
exports.APIDatabase = APIDatabase;
//# sourceMappingURL=APIDatabase.js.map