import { Column } from "../structures/Column";
import { ColumnSelectOptions, InnerJoinOptions, SortOptions, SqliteQueryOptions } from "../typings";
/**
 * Contains utility functions to make interacting with the database easier.
 */
declare class Util extends null {
    constructor();
    static mergeDefault(target: any, source: any): any;
    /**
     * Creates inner join options for a query.
     * @param options The options for joining tables.
     * @returns The created inner join query.
     */
    static makeInnerJoinOptions(options?: InnerJoinOptions[]): string;
    /**
     * Creates select options for a query.
     * @param options The options for this query selector.
     * @returns The created selector.
     */
    static makeSelectOptions(options?: string[] | "*" | ColumnSelectOptions[]): {
        query: string;
        renamedColumns: Record<string, string>;
    };
    /**
     * Makes filters for a query.
     * @param options The options for this filter.
     * @returns The returned filter for a query.
     */
    static makeWhereOptions(options?: SqliteQueryOptions): string;
    /**
     * Creates columns for a table.
     * @param data The object for columns.
     * @returns The columns that were created from the object.
     */
    static makeColumnsFrom(data: Record<string, any>): string;
    /**
     * Creates a string of sort options for this query.
     * @param options The options for sorting the query.
     * @returns The string to sort this query.
     */
    static makeSortOptions(options?: SortOptions): string;
    /**
     * Makes a string that is valid to insert values into sqlite.
     * @param data The object containing data.
     * @param columns The columns of the table.
     * @returns The string to use against sqlite.
     */
    static makeInsertValues(data: Record<string, any>, columns: Column[]): string;
    /**
     * Creates a set of values to update a row.
     * @param data The object data to update with.
     * @param columns The columns of the table.
     * @returns The string that can be used to update this row.
     */
    static makeSetValues(data: Record<string, any>, columns: Column[]): string;
    /**
     * Checks whether a number is valid for sqlite.
     * @param n The number to check.
     * @returns Whether the number is valid.
     */
    static isNumber(n: any): boolean;
}
export { Util };
//# sourceMappingURL=Util.d.ts.map